@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import re
+from datetime import datetime
 class Version(object):
     """ Parsing and comparing version strings
     """
@@ -34,3 +35,18 @@ VERSION = Version()
 #print(v.compare("1.5.0", "1.5.0"))
 #vs = ["999.999.999.999.999", "1.5.0", "2.3.555.0", "2.3.8", "5.1", "3", "0.9.6", "2.3.8.1", "2.3.5"]
 #print(sorted(vs, key=v.key))
+
+def TO_BPM_DATE(dt:datetime) -> int:
+    """ Converts a datetime to a BPM platform date/time value 
+    """
+    if not(dt):
+        return 0;
+    return int(dt.timestamp()*1000)
+
+def FROM_BPM_DATE(timestamp:int) -> datetime:
+    """ Converts a date / time value from the BPM platform to a datetime object
+    """
+    if timestamp == 0:
+        return None
+    return datetime.fromtimestamp(timestamp/1e3)
+
